set(figure(1),'Pointer','watch');

switch (get(handles.calc_type,'Value'))
  case 3
    disp('*******************************************************************');
    disp('*                                                                 *');
    disp('*  The TX pressure field is being calculated, please be patient.  *');
    disp('*                                                                 *');
    disp('*******************************************************************');

    [pressure, startTime] = calc_hp(probeHandle, measurementPoints);
    timeaftertx=startTime:1/samplingFrequency:startTime+(size(pressure,1)-1) / ...
    samplingFrequency;
    timeaftertx=timeaftertx-0.5*(length(conv(impulseResponse,excitationPulse))-1)/samplingFrequency;
    distaftertx=(timeaftertx)*soundSpeed;
    distaftertx=distaftertx*1000;   % convert to mm
    lambda=soundSpeed/centerFrequency;
    flags.calc_hp = 1;
  case 4
    disp('**********************************************************************');
    disp('*                                                                    *');
    disp('*  The TX/RX pressure field is being calculated, please be patient.  *');
    disp('*                                                                    *');
    disp('**********************************************************************');

    %%%%%% USE CALC_SCAT TO COMPUTE TX/RX FIELD %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    clear image_data dat psf
    % generate tx/rx image by shifting scatterers laterally 
    % leaving them centered around the focal point
    no_lines=size(measurementPoints,1);
    dx=latSampleIncr;
    shift=-floor(no_lines/2)*dx; % compute initial offset
    posshift=pos;
    % center target on focal point of transducer, then shift
    % the lateral location for each line
    posshift(:,3)=posshift(:,3)+focalPoint(3);
    posshift(:,2)=posshift(:,2)+focalPoint(2);  % this is typically 0
    posshift(:,1)=posshift(:,1)+focalPoint(1)+shift;
    image_data=zeros(300,no_lines);
    for i=1:no_lines
      [v,t1]=calc_scat(probeHandle, probeHandle, posshift, amp);
      % store the result
      image_data(1:max(size(v)),i)=v;
      times(i)=t1;
      % shift the scatterers
      posshift(:,1)=posshift(:,1)+dx;
    end
    % Adjust the data in time
    min_sample=min(times)*samplingFrequency;
    for i=1:no_lines
      % have to zero pad in front of some to align time step
      dat=[zeros(round(times(i)*samplingFrequency-min_sample),1); image_data(:,i)];
      psf(1:max(size(dat)),i)=dat;
    end

    % generate axes for image
    % first row in image corresponds to min(times) in seconds
    timetxrx=min(times):1/samplingFrequency:min(times)+(size(psf,1)-1)*1/samplingFrequency;
    timetxrxC = timetxrx;  % for use in Compounding
    timetxrx=timetxrx-0.5*(length(conv(excitationPulse,conv(impulseResponse,impulseResponse)))-1)/samplingFrequency;
    disttxrx=(timetxrx)*soundSpeed/2;
    disttxrx=disttxrx*1000;   % convert to mm

%  compute K-space by default whenever compute TX/RX field
    lambda=soundSpeed/centerFrequency;
    kpsf=fftshift(fft2(psf));
    fax=0:size(kpsf,1)-1;
    fax=(fax/max(fax))-.5;
    fsmplax=samplingFrequency/((soundSpeed/2)*1000);
    fax=fax*fsmplax;
    flat=0:size(kpsf,2)-1;
    flat=flat-max(flat)/2;
    fsmpllat=1/(latSampleIncr*1000);              % in samples/mm
    flat=flat*fsmpllat/max(flat);
    flat = (flat*latSampleIncr*1000);    % in cycles/mm
    flags.calc_k = 1;
    %compute envelope detected image
    env=abs(hilbert(psf));
    envsc=env/max(max(env));
    envsc=log(envsc+0.1);
    flags.calc_hhp = 1;

end
set(handles.calc_type,'Value',1);

% update the save menu, if you have computed txrxfield
if (flags.calc_hhp==1)
  delete(handles.save);
  handles.save  = uicontrol('Parent',a, ...
        'Units','normalized', ...
        'BackgroundColor',[0.701961 0.701961 0.701961], ...
        'Max',4, ...
        'Min',1, ...
        'Position',[.600 .06 .35 .04], ...
        'String',[ ...
                'Plot to save:                  '; ...
                '                               '; ...
                'Target file                    '; ...
                'TX/RX Field Image              '; ...
                'TX/RX Lateral Beamplot         '; ...
                'Kspace Image                   '; ...
                'Detected Image                 '], ...
        'Style','popupmenu', ...
        'Tag','PopupMenu1', ...
        'Callback','save_data', ...
        'HorizontalAlignment','left', ...
        'Value',1);
end
% update the graph menu
delete(handles.plot_type);
if (flags.calc_hp == 0) & (flags.calc_hhp == 0)
  handles.plot_type  = uicontrol('Parent',a, ...
  'Units','normalized', ...
  'BackgroundColor',[0.701961 0.701961 0.701961], ...
  'Max',3, ...
  'Min',1, ...
  'Position',[.04 .01 .47 .04], ...
  'String',[ ...
	  'Plot:                         '; ...
	  '                              '; ...
	  'Element Impulse Response      '; ...
	  'Excitation Pulse              '], ...
  'Style','popupmenu', ...
  'Tag','PopupMenu1', ...
  'Value',1, ...
  'HorizontalAlignment','left', ...
  'Callback','plot_graphs');
end;

if (flags.calc_hp == 1) & (flags.calc_hhp == 0)
  handles.plot_type  = uicontrol('Parent',a, ...
  'Units','normalized', ...
  'BackgroundColor',[0.701961 0.701961 0.701961], ...
  'Max',7, ...
  'Min',1, ...
  'Position',[.04 .01 .47 .04], ...
  'String',[ ...
	  'Plot:                         '; ...
	  '                              '; ...
	  'Element Impulse Response      '; ...
	  'Excitation Pulse              '; ...
	  'TX Field Image                '; ...
	  'TX Axial Waveform             '; ...
	  'TX Lateral Beamplot           '], ...
  'Style','popupmenu', ...
  'Tag','PopupMenu1', ...
  'Value',1, ...
  'HorizontalAlignment','left', ...
  'Callback','plot_graphs');
end;

if (flags.calc_hp == 0) & (flags.calc_hhp == 1) & (flags.calc_k == 1)
  handles.plot_type  = uicontrol('Parent',a, ...
  'Units','normalized', ...
  'BackgroundColor',[0.701961 0.701961 0.701961], ...
  'Max',8, ...
  'Min',1, ...
  'Position',[.04 .01 .47 .04], ...
  'String',[ ...
	  'Plot:                         '; ...
	  '                              '; ...
	  'Element Impulse Response      '; ...
	  'Excitation Pulse              '; ...
	  'TX/RX Field Image             '; ...
	  'TX/RX Axial Waveform          '; ...
	  'TX/RX Lateral Beamplot        '; ...
	  'K-Space TX/RX Field Image     '; ...
	  'K-Space Axial Slice           '; ...
	  'K-Space Lateral Slice         '; ...
	  'Detected Image                '; ...
	  'Detected Image Axial Slice    '; ...
	  'Detected Image Lateral Slice  '], ...
  'Style','popupmenu', ...
  'Tag','PopupMenu1', ...
  'Value',1, ...
  'HorizontalAlignment','left', ...
  'Callback','plot_graphs');
end;

if (flags.calc_hp == 1) & (flags.calc_hhp == 1) & (flags.calc_k == 1)
  handles.plot_type  = uicontrol('Parent',a, ...
  'Units','normalized', ...
  'BackgroundColor',[0.701961 0.701961 0.701961], ...
  'Max',11, ...
  'Min',1, ...
  'Position',[.04 .01 .47 .04], ...
  'String',[ ...
	  'Plot:                         '; ...
	  '                              '; ...
	  'Element Impulse Response      '; ...
	  'Excitation Pulse              '; ...
	  'TX Field Image                '; ...
	  'TX Axial Waveform             '; ...
	  'TX Lateral Beamplot           '; ...
	  'TX/RX Field Image             '; ...
	  'TX/RX Axial Waveform          '; ...
	  'TX/RX Lateral Beamplot        '; ...
	  'K-Space TX/RX Field Image     '; ...
	  'K-Space Axial Slice           '; ...
	  'K-Space Lateral Slice         '; ...
	  'Detected Image                '; ...
	  'Detected Image Axial Slice    '; ...
	  'Detected Image Lateral Slice  '], ...
  'Style','popupmenu', ...
  'Tag','PopupMenu1', ...
  'Value',1, ...
  'HorizontalAlignment','left', ...
  'Callback','plot_graphs');
end;
set(figure(1),'Pointer','arrow');
