% user _must_ recalculate after changing any values
flags.calc_hp = 0;
flags.calc_hhp = 0;
flags.calc_k = 0;

numElements = str2num(get(handles.number_elements,'String'));           
kerf = 1e-3 * str2num(get(handles.kerf,'String'));
width = 1e-3 * str2num(get(handles.width,'String'));
height = 1e-3 * str2num(get(handles.height,'String')); 
focalPoint = 1e-3 * [str2num(get(handles.focus_lateral,'String')) ...
		     str2num(get(handles.focus_elevation,'String')) ...
		     str2num(get(handles.focus_axial,'String'))];
latRange = 1e-3 * str2num(get(handles.calc_lateral_range,'String'));
latSampleIncr = 1e-3 * str2num(get(handles.calc_lateral_increment,'String'));
samplingFrequency = 1e6 * str2num(get(handles.sampling_freq,'String'));
centerFrequency = 1e6 * str2num(get(handles.center_freq,'String'));
fractionalBandwidth = str2num(get(handles.fractional_bandwidth,'String'))/100;
soundSpeed = str2num(get(handles.sound_speed,'String'));

set_field('fs',samplingFrequency);
set_field('c',soundSpeed);

% must compute width and height of subdivisions
% s.t. they meet criteria (d^2/4 lambda)
lambda=soundSpeed/samplingFrequency;
widthSubdivisions = ceil(width/(sqrt(4*lambda*focalPoint(3))));
heightSubdivisions = ceil(height/(sqrt(4*lambda*focalPoint(3))));

% overall array width
arraywidth=numElements*width+(numElements-1)*kerf;
% make lateral diffuse scatterer ROI a little bigger than lateral Range
latroisz=latRange+4*latSampleIncr;

% set position of hydrophones for Tx only meas.
clear measurementPoints
measurementPoints(:,1) = focalPoint(1)+(-latRange/2:latSampleIncr:latRange/2)';
measurementPoints(:,2) = focalPoint(2);
measurementPoints(:,3) = focalPoint(3);

lateralPosition=measurementPoints(:,1)*1000;  % convert to mm

probeHandle = xdc_linear_array(numElements, width, height, kerf, ...
      widthSubdivisions, heightSubdivisions, focalPoint);

tc = gauspuls('cutoff', centerFrequency, fractionalBandwidth, -6, -40);
t = -tc:1/samplingFrequency:tc;
impulseResponse =gauspuls(t, centerFrequency, fractionalBandwidth);
xdc_impulse(probeHandle, impulseResponse);
xdc_excitation(probeHandle, 1);

% Set the excitation pulse based on user selection:
% update the excitation pulse section

% if the fields do not exist yet, create them:
if (get(handles.excite_type,'Value') ~= 1) & (flags.non_delta == 0)
        handles.text_excite_center_frequency = uicontrol('Parent',a, ...
                'Units','normalized', ...
                'BackgroundColor',[0.701961 0.701961 0.701961], ...
                'Position',[.05 .24 .27 .04], ...
                'String','Center Frequency (MHz)', ...
                'Style','text', ...
                'HorizontalAlignment','left', ...
                'Tag','StaticText1');
	handles.text_excite_number_cycles = uicontrol('Parent',a, ...
		'Units','normalized', ...
		'BackgroundColor',[0.701961 0.701961 0.701961], ...
		'Position',[.05 .19 .27 .04], ...
		'String','Number of Cycles', ...
		'Style','text', ...
		'HorizontalAlignment','left', ...
		'Tag','StaticText1');
	handles.excite_center_frequency = uicontrol('Parent',a, ...
                'Units','normalized', ...
                'BackgroundColor',[1 1 1], ...
                'Position',[.42 .24 .08 .04], ...
                'String','7.5', ...
                'Style','edit', ...
                'Callback','store_params', ...
                'Tag','EditText1');
	handles.excite_number_cycles = uicontrol('Parent',a, ...
		'Units','normalized', ...
		'BackgroundColor',[1 1 1], ...
		'Position',[.42 .19 .08 .04], ...
		'String','5', ...
		'Style','edit', ...
		'Callback','store_params', ...
		'Tag','EditText1');
end;

% if going from nondelta -> delta, delete the fields
if (get(handles.excite_type,'Value') == 1) & (flags.non_delta == 1)
	delete(handles.text_excite_center_frequency);
	delete(handles.text_excite_number_cycles);
	delete(handles.excite_center_frequency);
	delete(handles.excite_number_cycles);
end;

% get the non-delta excitation pulse params
if (get(handles.excite_type,'Value') ~= 1)
  centerFrequencyExcite = 1e6*str2num(get(handles.excite_center_frequency,'String'));
  numCycles = str2num(get(handles.excite_number_cycles,'String'));
end;

% actually create the excitation pulse
switch get(handles.excite_type,'Value')
  case 1		% Delta function
    timeExcite=0;
    excitationPulse=1;	
    flags.non_delta = 0;
  case 2		% Sine function
    timeExcite=0:(1/samplingFrequency):(numCycles/centerFrequencyExcite); 
    excitationPulse=sin(2*pi*centerFrequencyExcite*timeExcite);
    flags.non_delta = 1;
  case 3		% Square function
    timeExcite=0:(1/samplingFrequency):(numCycles/centerFrequencyExcite);
    excitationPulse=(.5*square(2*pi*centerFrequencyExcite*timeExcite))+.5;
    flags.non_delta  = 1;
end

xdc_excitation(probeHandle, excitationPulse);
axres=length(conv(impulseResponse,excitationPulse))*soundSpeed/(2*samplingFrequency);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%add menu options for different target types
%%%%  assume default is point at focal point
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
if(get(handles.targ_type,'Value')==1 & flags.targ_type~=1)
 if (flags.targ_type==5)  % user defined
   % get rid of userdef fields
   delete(handles.text_targ_fname);
   delete(handles.targ_fname);
 elseif(flags.targ_type~=2)  % was either diffuse(3) or both (4) 
   % get rid of diffuse fields
   delete(handles.text_targ_roisz);
   delete(handles.targ_roisz);
   delete(handles.text_targ_cystdiam);
   delete(handles.targ_cystdiam);
   delete(handles.text_targ_scatdens);
   delete(handles.targ_scatdens);
   if(flags.targ_type==4)  % if were doing both, delete fields
     delete(handles.text_diffuse);
     delete(handles.text_targ_ampratio);
     delete(handles.targ_ampratio);
     delete(handles.text_targ_numaxpts);
     delete(handles.targ_numaxpts);
     delete(handles.text_targ_distaxpts);
     delete(handles.targ_distaxpts);
     delete(handles.text_calc_axial);
     delete(handles.calc_axial);
     delete(handles.text_targ_numlatpts);
     delete(handles.targ_numlatpts);
     delete(handles.text_targ_distlatpts);
     delete(handles.targ_distlatpts);
     delete(handles.text_calc_lateral);
     delete(handles.calc_lateral);
   end
 else % it was 2, structured
   delete(handles.text_targ_numaxpts);
   delete(handles.targ_numaxpts);
   delete(handles.text_targ_distaxpts);
   delete(handles.targ_distaxpts);
   delete(handles.text_calc_axial);
   delete(handles.calc_axial);
   delete(handles.text_targ_numlatpts);
   delete(handles.targ_numlatpts);
   delete(handles.text_targ_distlatpts);
   delete(handles.targ_distlatpts);
   delete(handles.text_calc_lateral);
   delete(handles.calc_lateral);
 end
end
if(get(handles.targ_type,'Value')==2 & flags.targ_type~=2)
 if (flags.targ_type==5)  % user defined
   % get rid of userdef fields
   delete(handles.text_targ_fname);
   delete(handles.targ_fname);
 elseif(flags.targ_type~=1)
   % was diffuse, now want structured
   % get rid of other diffuse fields
   delete(handles.text_targ_roisz);
   delete(handles.targ_roisz);
   delete(handles.text_targ_cystdiam);
   delete(handles.targ_cystdiam);
   delete(handles.text_targ_scatdens);
   delete(handles.targ_scatdens);
   if(flags.targ_type==4)  % if were doing both, keep fields you had
     delete(handles.text_diffuse);
     delete(handles.text_targ_ampratio);
     delete(handles.targ_ampratio);
   end
 end
 if(flags.targ_type~=4 )  % need to set def. and def menu
   targ_numaxpts='1';
   targ_distaxpts='0.5';
   calc_axial='0';
   targ_numlatpts='1';
   targ_distlatpts='0.5';
   calc_lateral='0';
   % add structured fields
   handles.text_targ_numaxpts = uicontrol('Parent',a, ...
          'Units','normalized', ...
          'BackgroundColor',[0.701961 0.701961 0.701961], ...
          'Position',[.600 .67 .27 .04], ...
          'String','Number of Axial Points', ...
          'HorizontalAlignment','left', ...
          'Style','text', ...
          'Tag','StaticText1');
   handles.text_targ_distaxpts = uicontrol('Parent',a, ...
          'Units','normalized', ...
          'BackgroundColor',[0.701961 0.701961 0.701961], ...
          'Position',[.600 .62 .27 .04], ...
          'String','Dist. b/t Axial Points (mm)', ...
          'HorizontalAlignment','left', ...
          'Style','text', ...
          'Tag','StaticText1');
   handles.text_calc_axial = uicontrol('Parent',a, ...
          'Units','normalized', ...
          'BackgroundColor',[0.701961 0.701961 0.701961], ...
          'Position',[.600 .57 .27 .04], ...
          'String','Axial Dist. from Focus (mm)', ...
          'HorizontalAlignment','left', ...
          'Style','text', ...
          'Tag','StaticText1');
   handles.text_targ_numlatpts = uicontrol('Parent',a, ...
          'Units','normalized', ...
          'BackgroundColor',[0.701961 0.701961 0.701961], ...
          'Position',[.600 .52 .27 .04], ...
          'String','Number of Lateral Points', ...
          'HorizontalAlignment','left', ...
          'Style','text', ...
          'Tag','StaticText1');
   handles.text_targ_distlatpts = uicontrol('Parent',a, ...
          'Units','normalized', ...
          'BackgroundColor',[0.701961 0.701961 0.701961], ...
          'Position',[.600 .47 .27 .04], ...
          'String','Dist. b/t Lateral Points (mm)', ...
          'HorizontalAlignment','left', ...
          'Style','text', ...
          'Tag','StaticText1');
   handles.text_calc_lateral = uicontrol('Parent',a, ...
          'Units','normalized', ...
          'BackgroundColor',[0.701961 0.701961 0.701961], ...
          'Position',[.600 .42 .27 .04], ...
          'String','Lat. Dist. from Focus (mm)', ...
          'HorizontalAlignment','left', ...
          'Style','text', ...
          'Tag','StaticText1');
   %%%  Now set values of these fields
   handles.targ_numaxpts = uicontrol('Parent',a, ...
          'Units','normalized', ...
          'BackgroundColor',[1 1 1], ...
          'Position',[.870 .67 .08 .040], ...
          'String',targ_numaxpts, ...
          'Style','edit', ...
          'Callback','store_params', ...
          'Tag','EditText1');
   handles.targ_distaxpts = uicontrol('Parent',a, ...
          'Units','normalized', ...
          'BackgroundColor',[1 1 1], ...
          'Position',[.870 .62 .08 .040], ...
          'String',targ_distaxpts, ...
          'Style','edit', ...
          'Callback','store_params', ...
          'Tag','EditText1');
   handles.calc_axial = uicontrol('Parent',a, ...
          'Units','normalized', ...
          'BackgroundColor',[1 1 1], ...
          'Position',[.870 .57 .08 .040], ...
          'String',calc_axial, ...
          'Style','edit', ...
          'Callback','store_params', ...
          'Tag','EditText1');
   handles.targ_numlatpts = uicontrol('Parent',a, ...
          'Units','normalized', ...
          'BackgroundColor',[1 1 1], ...
          'Position',[.870 .52 .08 .040], ...
          'String',targ_numlatpts, ...
          'Style','edit', ...
          'Callback','store_params', ...
          'Tag','EditText1');
   handles.targ_distlatpts = uicontrol('Parent',a, ...
          'Units','normalized', ...
          'BackgroundColor',[1 1 1], ...
          'Position',[.870 .47 .08 .040], ...
          'String',targ_distlatpts, ...
          'Style','edit', ...
          'Callback','store_params', ...
          'Tag','EditText1');
   handles.calc_lateral = uicontrol('Parent',a, ...
          'Units','normalized', ...
          'BackgroundColor',[1 1 1], ...
          'Position',[.870 .42 .08 .040], ...
          'String',calc_lateral, ...
          'Style','edit', ...
          'Callback','store_params', ...
          'Tag','EditText1');
  end
end
if(get(handles.targ_type,'Value')==3 & flags.targ_type~=3) % diffuse only
 if (flags.targ_type==5)  % user defined
   % get rid of userdef fields
   delete(handles.text_targ_fname);
   delete(handles.targ_fname);
 elseif(flags.targ_type~=1)
   delete(handles.text_targ_numaxpts);
   delete(handles.targ_numaxpts);
   delete(handles.text_targ_distaxpts);
   delete(handles.targ_distaxpts);
   delete(handles.text_calc_axial);
   delete(handles.calc_axial);
   delete(handles.text_targ_numlatpts);
   delete(handles.targ_numlatpts);
   delete(handles.text_targ_distlatpts);
   delete(handles.targ_distlatpts);
   delete(handles.text_calc_lateral);
   delete(handles.calc_lateral);
 end
 if(flags.targ_type==4)  % if were doing both, keep fields you had
   targ_roisz=get(handles.targ_roisz,'String');
   targ_cystdiam=get(handles.targ_cystdiam,'String');
   targ_scatdens=get(handles.targ_scatdens,'String');
   % now delete these fields so you can reposition them
   delete(handles.text_diffuse);
   delete(handles.text_targ_ampratio);
   delete(handles.targ_ampratio);
   delete(handles.text_targ_roisz);
   delete(handles.targ_roisz);
   delete(handles.text_targ_cystdiam);
   delete(handles.targ_cystdiam);
   delete(handles.text_targ_scatdens);
   delete(handles.targ_scatdens);
 else  % set defaults
   targ_roisz='1';
   targ_cystdiam='0';
   targ_scatdens='10';
 end 
 % now setup menus
 handles.text_targ_roisz = uicontrol('Parent',a, ...
        'Units','normalized', ...
        'BackgroundColor',[0.701961 0.701961 0.701961], ...
        'Position',[.600 .67 .27 .04], ...
        'String','Diffuse Axial ROI Size (mm)', ...
        'HorizontalAlignment','left', ...
        'Style','text', ...
        'Tag','StaticText1');
 handles.text_targ_cystdiam = uicontrol('Parent',a, ...
        'Units','normalized', ...
        'BackgroundColor',[0.701961 0.701961 0.701961], ...
        'Position',[.600 .62 .27 .04], ...
        'String','Diameter of Cyst (mm)', ...
        'HorizontalAlignment','left', ...
        'Style','text', ...
        'Tag','StaticText1');
 handles.text_targ_scatdens = uicontrol('Parent',a, ...
        'Units','normalized', ...
        'BackgroundColor',[0.701961 0.701961 0.701961], ...
        'Position',[.600 .57 .27 .04], ...
        'String','Diffuse Scatterer Density', ...
        'HorizontalAlignment','left', ...
        'Style','text', ...
        'Tag','StaticText1');
 % set values
 handles.targ_roisz = uicontrol('Parent',a, ...
        'Units','normalized', ...
        'BackgroundColor',[1 1 1], ...
        'Position',[.870 .67 .08 .040], ...
        'String',targ_roisz, ...
        'Style','edit', ...
        'Callback','store_params', ...
        'Tag','EditText1');
 handles.targ_cystdiam = uicontrol('Parent',a, ...
        'Units','normalized', ...
        'BackgroundColor',[1 1 1], ...
        'Position',[.870 .62 .08 .040], ...
        'String',targ_cystdiam, ...
        'Style','edit', ...
        'Callback','store_params', ...
        'Tag','EditText1');
 handles.targ_scatdens = uicontrol('Parent',a, ...
        'Units','normalized', ...
        'BackgroundColor',[1 1 1], ...
        'Position',[.870 .57 .08 .040], ...
        'String',targ_scatdens, ...
        'Style','edit', ...
        'Callback','store_params', ...
        'Tag','EditText1');
end
if(get(handles.targ_type,'Value')==4 & flags.targ_type~=4)
 targ_ampratio=20;  % set amplitude ratio 
 if (flags.targ_type~=2 & flags.targ_type~=3 & flags.targ_type~=4) % set vals
   targ_numaxpts='1';   % set structuresd defaults 
   targ_distaxpts='0.5';
   calc_axial='0';
   targ_numlatpts='1';
   targ_distlatpts='0.5';
   calc_lateral='0';
   targ_roisz='1';  % set diffuse defaults 
   targ_cystdiam='0';
   targ_scatdens='10';
   if (flags.targ_type==5)  % user defined
     % get rid of userdef fields
     delete(handles.text_targ_fname);
     delete(handles.targ_fname);
   end
 elseif flags.targ_type==2  % get prev. structured values
   targ_numaxpts=get(handles.targ_numaxpts,'String');
   targ_distaxpts=get(handles.targ_distaxpts,'String');
   calc_axial=get(handles.calc_axial,'String');
   targ_numlatpts=get(handles.targ_numlatpts,'String');
   targ_distlatpts=get(handles.targ_distlatpts,'String');
   calc_lateral=get(handles.calc_lateral,'String');
   targ_roisz='1';  % set diffuse defaults 
   targ_cystdiam='0';
   targ_scatdens='10';
   % get rid of prev. menu entries
   delete(handles.text_targ_numaxpts);
   delete(handles.targ_numaxpts);
   delete(handles.text_targ_distaxpts);
   delete(handles.targ_distaxpts);
   delete(handles.text_calc_axial);
   delete(handles.calc_axial);
   delete(handles.text_targ_numlatpts);
   delete(handles.targ_numlatpts);
   delete(handles.text_targ_distlatpts);
   delete(handles.targ_distlatpts);
   delete(handles.text_calc_lateral);
   delete(handles.calc_lateral);
 else  % flags.targ_type must = 3, so get prev.diffuse values
   targ_roisz=get(handles.targ_roisz,'String');
   targ_cystdiam=get(handles.targ_cystdiam,'String');
   targ_scatdens=get(handles.targ_scatdens,'String');
   targ_numaxpts='1';   % set structured defaults 
   targ_distaxpts='0.5';
   calc_axial='0';
   targ_numlatpts='1';
   targ_distlatpts='0.5';
   calc_lateral='0';
   % get rid of prev. menu entries
   delete(handles.text_targ_roisz);
   delete(handles.targ_roisz);
   delete(handles.text_targ_cystdiam);
   delete(handles.targ_cystdiam);
   delete(handles.text_targ_scatdens);
   delete(handles.targ_scatdens);
 end 
 % now reset the menu to have both structured and diffuse
 handles.text_targ_numaxpts = uicontrol('Parent',a, ...
        'Units','normalized', ...
        'BackgroundColor',[0.701961 0.701961 0.701961], ...
        'Position',[.600 .67 .27 .04], ...
        'String','Number of Axial Points', ...
        'HorizontalAlignment','left', ...
        'Style','text', ...
        'Tag','StaticText1');
 handles.text_targ_distaxpts = uicontrol('Parent',a, ...
        'Units','normalized', ...
        'BackgroundColor',[0.701961 0.701961 0.701961], ...
        'Position',[.600 .62 .27 .04], ...
        'String','Dist. b/t Axial Points (mm)', ...
        'HorizontalAlignment','left', ...
        'Style','text', ...
        'Tag','StaticText1');
 handles.text_calc_axial = uicontrol('Parent',a, ...
        'Units','normalized', ...
        'BackgroundColor',[0.701961 0.701961 0.701961], ...
        'Position',[.600 .57 .27 .04], ...
        'String','Axial Dist. from Focus (mm)', ...
        'HorizontalAlignment','left', ...
        'Style','text', ...
        'Tag','StaticText1');
 handles.text_targ_numlatpts = uicontrol('Parent',a, ...
        'Units','normalized', ...
        'BackgroundColor',[0.701961 0.701961 0.701961], ...
        'Position',[.600 .52 .27 .04], ...
        'String','Number of Lateral Points', ...
        'HorizontalAlignment','left', ...
        'Style','text', ...
        'Tag','StaticText1');
 handles.text_targ_distlatpts = uicontrol('Parent',a, ...
        'Units','normalized', ...
        'BackgroundColor',[0.701961 0.701961 0.701961], ...
        'Position',[.600 .47 .27 .04], ...
        'String','Dist. b/t Lateral Points (mm)', ...
        'HorizontalAlignment','left', ...
        'Style','text', ...
        'Tag','StaticText1');
 handles.text_calc_lateral = uicontrol('Parent',a, ...
        'Units','normalized', ...
        'BackgroundColor',[0.701961 0.701961 0.701961], ...
        'Position',[.600 .42 .27 .04], ...
        'String','Lat. Dist. from Focus (mm)', ...
        'HorizontalAlignment','left', ...
        'Style','text', ...
        'Tag','StaticText1');
 handles.text_diffuse = uicontrol('Parent',a, ...
        'Units','normalized', ...
        'BackgroundColor',[0.701961 0.701961 0.701961], ...
        'Position',[.600 .37 .27 .04], ...
        'String','Diffuse Parameters:', ...
        'HorizontalAlignment','left', ...
        'Style','text', ...
        'Tag','StaticText1');
 handles.text_targ_roisz = uicontrol('Parent',a, ...
        'Units','normalized', ...
        'BackgroundColor',[0.701961 0.701961 0.701961], ...
        'Position',[.600 .32 .27 .04], ...
        'String','Diffuse ROI Size (mm)', ...
        'HorizontalAlignment','left', ...
        'Style','text', ...
        'Tag','StaticText1');
 handles.text_targ_cystdiam = uicontrol('Parent',a, ...
        'Units','normalized', ...
        'BackgroundColor',[0.701961 0.701961 0.701961], ...
        'Position',[.600 .27 .27 .04], ...
        'String','Diameter of Cyst (mm)', ...
        'HorizontalAlignment','left', ...
        'Style','text', ...
        'Tag','StaticText1');
 handles.text_targ_scatdens = uicontrol('Parent',a, ...
        'Units','normalized', ...
        'BackgroundColor',[0.701961 0.701961 0.701961], ...
        'Position',[.600 .22 .27 .04], ...
        'String','Diffuse Scatterer Density', ...
        'HorizontalAlignment','left', ...
        'Style','text', ...
        'Tag','StaticText1');
 handles.text_targ_ampratio = uicontrol('Parent',a, ...
        'Units','normalized', ...
        'BackgroundColor',[0.701961 0.701961 0.701961], ...
        'Position',[.600 .17 .27 .04], ...
        'String','Amplitude Ratio: struc/diff', ...
        'HorizontalAlignment','left', ...
        'Style','text', ...
        'Tag','StaticText1');
 %%%  Now set values of these fields
 handles.targ_numaxpts = uicontrol('Parent',a, ...
        'Units','normalized', ...
        'BackgroundColor',[1 1 1], ...
        'Position',[.870 .67 .08 .040], ...
        'String',targ_numaxpts, ...
        'Style','edit', ...
        'Callback','store_params', ...
        'Tag','EditText1');
 handles.targ_distaxpts = uicontrol('Parent',a, ...
        'Units','normalized', ...
        'BackgroundColor',[1 1 1], ...
        'Position',[.870 .62 .08 .040], ...
        'String',targ_distaxpts, ...
        'Style','edit', ...
        'Callback','store_params', ...
        'Tag','EditText1');
 handles.calc_axial = uicontrol('Parent',a, ...
        'Units','normalized', ...
        'BackgroundColor',[1 1 1], ...
        'Position',[.870 .57 .08 .040], ...
        'String',calc_axial, ...
        'Style','edit', ...
        'Callback','store_params', ...
        'Tag','EditText1');
 handles.targ_numlatpts = uicontrol('Parent',a, ...
        'Units','normalized', ...
        'BackgroundColor',[1 1 1], ...
        'Position',[.870 .52 .08 .040], ...
        'String',targ_numlatpts, ...
        'Style','edit', ...
        'Callback','store_params', ...
        'Tag','EditText1');
 handles.targ_distlatpts = uicontrol('Parent',a, ...
        'Units','normalized', ...
        'BackgroundColor',[1 1 1], ...
        'Position',[.870 .47 .08 .040], ...
        'String',targ_distlatpts, ...
        'Style','edit', ...
        'Callback','store_params', ...
        'Tag','EditText1');
 handles.calc_lateral = uicontrol('Parent',a, ...
        'Units','normalized', ...
        'BackgroundColor',[1 1 1], ...
        'Position',[.870 .42 .08 .040], ...
        'String',calc_lateral, ...
        'Style','edit', ...
        'Callback','store_params', ...
        'Tag','EditText1');
 handles.targ_roisz = uicontrol('Parent',a, ...
        'Units','normalized', ...
        'BackgroundColor',[1 1 1], ...
        'Position',[.870 .32 .08 .040], ...
        'String',targ_roisz, ...
        'Style','edit', ...
        'Callback','store_params', ...
        'Tag','EditText1');
 handles.targ_cystdiam = uicontrol('Parent',a, ...
        'Units','normalized', ...
        'BackgroundColor',[1 1 1], ...
        'Position',[.870 .27 .08 .040], ...
        'String',targ_cystdiam, ...
        'Style','edit', ...
        'Callback','store_params', ...
        'Tag','EditText1');
 handles.targ_scatdens = uicontrol('Parent',a, ...
        'Units','normalized', ...
        'BackgroundColor',[1 1 1], ...
        'Position',[.870 .22 .08 .040], ...
        'String',targ_scatdens, ...
        'Style','edit', ...
        'Callback','store_params', ...
        'Tag','EditText1');
 handles.targ_ampratio = uicontrol('Parent',a, ...
        'Units','normalized', ...
        'BackgroundColor',[1 1 1], ...
        'Position',[.870 .17 .08 .040], ...
        'String',targ_ampratio, ...
        'Style','edit', ...
        'Callback','store_params', ...
        'Tag','EditText1');
end
if(get(handles.targ_type,'Value')==5 & flags.targ_type~=5)
 if (flags.targ_type==1)  % point, no menu manip. required
 elseif(flags.targ_type~=2)  % was either diffuse(3) or both (4) 
   % get rid of diffuse fields
   delete(handles.text_targ_roisz);
   delete(handles.targ_roisz);
   delete(handles.text_targ_cystdiam);
   delete(handles.targ_cystdiam);
   delete(handles.text_targ_scatdens);
   delete(handles.targ_scatdens);
   if(flags.targ_type==4)  % if were doing both, delete fields
     delete(handles.text_diffuse);
     delete(handles.text_targ_ampratio);
     delete(handles.targ_ampratio);
     delete(handles.text_targ_numaxpts);
     delete(handles.targ_numaxpts);
     delete(handles.text_targ_distaxpts);
     delete(handles.targ_distaxpts);
     delete(handles.text_calc_axial);
     delete(handles.calc_axial);
     delete(handles.text_targ_numlatpts);
     delete(handles.targ_numlatpts);
     delete(handles.text_targ_distlatpts);
     delete(handles.targ_distlatpts);
     delete(handles.text_calc_lateral);
     delete(handles.calc_lateral);
   end
 else % it was 2, structured
   delete(handles.text_targ_numaxpts);
   delete(handles.targ_numaxpts);
   delete(handles.text_targ_distaxpts);
   delete(handles.targ_distaxpts);
   delete(handles.text_calc_axial);
   delete(handles.calc_axial);
   delete(handles.text_targ_numlatpts);
   delete(handles.targ_numlatpts);
   delete(handles.text_targ_distlatpts);
   delete(handles.targ_distlatpts);
   delete(handles.text_calc_lateral);
   delete(handles.calc_lateral);
 end
 % add input for filename
 handles.text_targ_fname = uicontrol('Parent',a, ...
        'Units','normalized', ...
        'BackgroundColor',[0.701961 0.701961 0.701961], ...
        'Position',[.600 .67 .27 .04], ...
        'String','Filename', ...
        'HorizontalAlignment','left', ...
        'Style','text', ...
        'Tag','StaticText1');
 %%%  Now set value of this field
 handles.targ_fname = uicontrol('Parent',a, ...
        'Units','normalized', ...
        'BackgroundColor',[1 1 1], ...
        'Position',[.72 .67 .23 .040], ...
        'String','point', ...
        'Style','edit', ...
        'Callback','load_usertarg', ...
        'Tag','EditText1');
end

switch get(handles.targ_type,'Value') %determine position and amp of scatterers
  case 1 %  point target
    clear pos amp 
    pos=[0 0 0];
    amp=1;
    flags.targ_type=1;
  case 2  % store the values you need
    numaxpts = str2num(get(handles.targ_numaxpts,'String'));
    distaxpts = 1e-3 * str2num(get(handles.targ_distaxpts,'String'));
    axDistFromFocus = 1e-3 * str2num(get(handles.calc_axial,'String')); 
    numlatpts = str2num(get(handles.targ_numlatpts,'String'));
    distlatpts = 1e-3 * str2num(get(handles.targ_distlatpts,'String'));
    latDistFromFocus = 1e-3 * str2num(get(handles.calc_lateral,'String'));
    % compute scatter file
    clear pos amp 
    [pos amp]=calc_struct(numaxpts,numlatpts,distaxpts,distlatpts,focalPoint,latDistFromFocus,axDistFromFocus);
    flags.targ_type=2;
  case 3  % store values you need
    axroisz = 1e-3 * str2num(get(handles.targ_roisz,'String'));
    cystdiam = 1e-3 * str2num(get(handles.targ_cystdiam,'String'));
    scatdens = str2num(get(handles.targ_scatdens,'String'));
    % compute scatter file
    clear pos amp
    [pos, amp] = calc_diffuse(lambda,focalPoint,arraywidth,axres,scatdens,...
                  cystdiam, axroisz,latroisz);
    flags.targ_type=3;
  case 4  % store values you need
    numaxpts = str2num(get(handles.targ_numaxpts,'String'));
    distaxpts = 1e-3 * str2num(get(handles.targ_distaxpts,'String'));
    axDistFromFocus = 1e-3 * str2num(get(handles.calc_axial,'String')); 
    numlatpts = str2num(get(handles.targ_numlatpts,'String'));
    distlatpts = 1e-3 * str2num(get(handles.targ_distlatpts,'String'));
    latDistFromFocus = 1e-3 * str2num(get(handles.calc_lateral,'String'));
    axroisz = 1e-3 * str2num(get(handles.targ_roisz,'String'));
    cystdiam = 1e-3 * str2num(get(handles.targ_cystdiam,'String'));
    scatdens = str2num(get(handles.targ_scatdens,'String'));
    ampratio=str2num(get(handles.targ_ampratio,'String'));
    % compute scatter file
    clear pos amp 
    [posstruct ampstruct]=calc_struct(numaxpts,numlatpts,distaxpts,...
                       distlatpts,focalPoint,latDistFromFocus,axDistFromFocus);
    [posdiff, ampdiff] = calc_diffuse(lambda,focalPoint,arraywidth,axres,...
                       scatdens, cystdiam, axroisz,latroisz);
    pos=[posstruct;posdiff];
    amp=[ampratio*ampstruct;ampdiff]; % scale structured and combine
    flags.targ_type=4;
  case 5 % load the named file
    load_usertarg;
    flags.targ_type=5;
end

% revert plot  and calc and save menus to no-calculations form
delete(handles.plot_type);
handles.plot_type  = uicontrol('Parent',a, ...
	'Units','normalized', ...
	'BackgroundColor',[0.701961 0.701961 0.701961], ...
	'Max',4, ...
	'Min',1, ...
	'Position',[.04 .01 .47 .04], ...
	'String',[ ...
		'Plot:                         '; ...
		'                              '; ...
		'Element Impulse Response      '; ...
		'Excitation Pulse              '], ...
	'Style','popupmenu', ...
	'Tag','PopupMenu1', ...
	'Value',1, ...
	'HorizontalAlignment','left', ...
	'Callback','plot_graphs');

delete(handles.calc_type);
handles.calc_type  = uicontrol('Parent',a, ...
        'Units','normalized', ...
        'BackgroundColor',[0.701961 0.701961 0.701961], ...
        'Max',4, ...
        'Min',1, ...
        'Position',[.04 .06 .47 .04], ...
        'String',[ ...
                'Calculate:                     '; ...
                '                               '; ...
                'TX Pressure Field              '; ...
                'TX/RX Pressure Field           '], ...
        'Style','popupmenu', ...
        'Tag','PopupMenu1', ...
        'Callback','calc_field_2', ...
        'HorizontalAlignment','left', ...
        'Value',1);

delete(handles.save);
handles.save  = uicontrol('Parent',a, ...
        'Units','normalized', ...
        'BackgroundColor',[0.701961 0.701961 0.701961], ...
        'Max',4, ...
        'Min',1, ...
        'Position',[.600 .06 .35 .04], ...
        'String',[ ...
                'Plot to save:                  '; ...
                '                               '; ...
                'Target file                    '], ...
        'Style','popupmenu', ...
        'Tag','PopupMenu1', ...
        'Callback','save_data', ...
        'HorizontalAlignment','left', ...
        'Value',1);

