clear all; clc; close all;

addpath('fieldII\matlab');
addpath('other_code');

tStart = tic;

field_init(0);

% Generate the transducer apertures for send and receive
f0 = 5e6; % Transducer center frequency [Hz]
fs = 40e6; % Sampling frequency [Hz]
c = 1540; % Speed of sound [m/s]
lambda = c / f0; % Wave length [m]
pitch = 0.3/1000;
% pitch_r = pitch/2;
pitch_r = pitch;
width = .95*pitch;
width_r = .95*pitch_r;
element_height = 10/1000; % Height of element [m]
kerf = pitch-width; % Kerf [m]
kerf_r = pitch_r - width_r;
focus = [0 0 30]/1000; % Fixed focal point [m]
N_elements = 128; % Number of elements in the transducer
N_elements_r = 128;

N_active = N_elements; % Active elements in the transducer

% Set the sampling frequency
set_sampling(fs);

% Generate aperture for emission
emit_aperture = xdc_linear_array(N_elements, width, element_height, kerf, 1, 1, focus);

% Set the impulse response and excitation of the emit aperture
impulse_response = sin(2*pi*f0*(0:1/fs:2/f0));
impulse_response = impulse_response .* hanning(max(size(impulse_response)))';
xdc_impulse(emit_aperture, impulse_response);

excitation = sin(2*pi*f0*(0:1/fs:2/f0));
xdc_excitation(emit_aperture, excitation);

% Generate aperture for reception
receive_aperture = xdc_linear_array(N_elements_r, width_r, element_height, kerf_r, 1, 1, focus);

% Set the impulse response for the receive aperture
xdc_impulse(receive_aperture, impulse_response);

%%% phantom#1
phantom_positions = [0 0 25] / 1000;   %  The position of the phantom
[m n] = size(phantom_positions);
phantom_amplitudes = 20*ones(m,1);      %  The amplitude of the back-scatter

%%% phantom#2
% N = 200;
% x_l = 20/1000;
% y_l = 10/1000;
% z_l = 20/1000;
% z_start = 5/1000;
% x_k = (rand(N,1)-0.5)*x_l;
% y_k = (rand(N,1)-0.5)*y_l;
% z_k = (rand(N,1))*z_l + z_start;
% phantom_positions = [x_k y_k z_k];
% phantom_amplitudes = rand(N,1);

%%% phantom#3
[phantom_positions, phantom_amplitudes] = cyst_phantom(1000);

% Simulate ultrasound data
[v,t] = calc_scat_all (emit_aperture, receive_aperture, phantom_positions, phantom_amplitudes, 1);

% Free space for apertures
xdc_free(emit_aperture)
xdc_free(receive_aperture)

prebeam = zeros(size(v,1),N_elements,N_elements);

%  make data similar to daq
for i = 1:N_elements
    
    prebeam(:,:,i) = v(:,(i-1)*N_elements+1:((i-1)*N_elements+1)+(N_elements-1));
    
end

%%

% sum1 = zeros(1691,N_elements); % for phantom#1
sum1 = zeros(4681,N_elements); % for phantom#3

for j = 1:128 %1:N_elements
    im = prebeam(:,:,j);
    for i = 1:N_elements
        rf_no_env = vertcat(zeros(round(t*fs),1), im(:,i));
        no_env(1:size(rf_no_env,1),i) = rf_no_env;
    end
    out = sa_reconstruction(no_env, j, 0.3);
    sum1 = sum1 + out;
    temp(:,:,j) = sum1;
end

bf_image = sum1;
bf_image = abs(hilbert(bf_image)); % Envelope detection
bf_image = bf_image / max(max(bf_image));

bf_image_p = 20*log10(bf_image + 0.001);
for i = 1:N_elements
    for j = 1:size(bf_image_p,1)
        if bf_image_p(j,i) < -30
            bf_image_p(j,i) = -30;
        end
    end
end
y = [1 size(bf_image_p(:,:),1)] / 40e6 * 1540 * 1e3;
x = [1 size(bf_image_p(:,:),2)] / N_elements * 38.4/4;

figure;
imagesc(x,y,bf_image_p(:,:))
colormap(gray);
