clear all; close all; clc;

addpath('fieldII\matlab');
addpath('other_code');

tStart = tic;

field_init(0);

% Generate the transducer apertures for send and receive
f0 = 5e6; % Transducer center frequency [Hz]
fs = 40e6; % Sampling frequency [Hz]
c = 1540; % Speed of sound [m/s]
lambda = c / f0; % Wave length [m]
pitch = 0.15/1000;
% pitch_r = pitch/2;
pitch_r = pitch;
width = .95*pitch;
width_r = .95*pitch_r;
element_height = 10/1000; % Height of element [m]
kerf = pitch-width; % Kerf [m]
kerf_r = pitch_r - width_r;
focus = [0 0 30]/1000; % Fixed focal point [m]
N_elements = 64; % Number of elements in the transducer
N_elements_r = 64;
N_active = 1; % Active elements in the transducer

% Set the sampling frequency
set_sampling(fs);

% Generate aperture for emission
emit_aperture = xdc_linear_array(N_elements, width, element_height, kerf, 1, 1, focus);

% Set the impulse response and excitation of the emit aperture
impulse_response = sin(2*pi*f0*(0:1/fs:2/f0));
impulse_response = impulse_response .* hanning(max(size(impulse_response)))';
xdc_impulse(emit_aperture, impulse_response);

excitation = sin(2*pi*f0*(0:1/fs:2/f0));
xdc_excitation(emit_aperture, excitation);

% Generate aperture for reception
receive_aperture = xdc_linear_array(N_elements_r, width_r, element_height, kerf_r, 1, 1, focus);

% Set the impulse response for the receive aperture
xdc_impulse(receive_aperture, impulse_response);
%
%  Define the point phantom
phantom_positions = [0 0 35] / 1000;   %  The position of the phantom
[m n] = size(phantom_positions);
phantom_amplitudes = 20*ones(m,1);      %  The amplitude of the back-scatter

% Load the cyst phantom
%
% Create a computer model of a cyst phantom. The phantom contains
% five point targets separated by 5 mm and a 10 mm water filled cyst.
% All scatterers are situated in a box of (x,y,z)=(40,10,50) mm.
%
% Calling: [positions, amp] = cyst_phantom (N);
% Parameters: N - Number of scatterers in the phantom
% Output: positions - Positions of the scatterers.
%         amp - amplitude of the scatterers.
% [phantom_positions, phantom_amplitudes] = cyst_phantom(10000);

% Do linear array imaging
no_lines = N_elements;%N_elements - N_active + 1; % Number of A-lines in image
dx = width; % Increment for image
z_focus = 30/1000;

% Pre-allocate some storage
image_data = zeros(3000,N_elements_r);
% RFframe = zeros(2000,N_elements_r,N_elements);


xdc_focus_times(emit_aperture,0,zeros(1,N_elements));
xdc_focus_times(receive_aperture,0,zeros(1,N_elements_r));

for i = 1:no_lines
    xdc_apodization(emit_aperture,0,[zeros(1,i-1) 1 zeros(1, N_elements - i)]);
    
    % Calculate the received response
    [v, t1] = calc_scat_multi(emit_aperture, receive_aperture, phantom_positions, phantom_amplitudes);
    rf = v;
    RFframe(1:size(v,1),1:size(v,2),i) = rf;
    v2 = v(:,i);
    image_data(1:max(size(v2)),i) = v2;
    times(i) = t1;
    disp(' ');
end

% Free space for apertures
xdc_free(emit_aperture)
xdc_free(receive_aperture)

% Adjust the data in time and display it as a gray scale image
min_sample = 0;

for i = 1:N_elements_r
    rf_no_env = vertcat(zeros(round(times(round(i))*fs-min_sample),1), image_data(:,i));
    rf_env = abs(hilbert([zeros(round(times(round(i))*fs-min_sample),1); image_data(:,i)]));
    no_env(1:size(rf_no_env,1),i) = rf_no_env;
    env(1:size(rf_env,1),i) = rf_env;
end

for j = 1:4000
    plainRF(round(j/2),:) = no_env(j,:);
end

% Make logarithmic compression to a 60 dB dynamic range with proper units on the axis
env_dB = 20*log10(env);
env_dB = env_dB-max(max(env_dB));
env_gray = 127*(env_dB + 60) / 60;
depth = ( (0:size(env,1) - 1) + min_sample )/fs * c/2;
x = ( (1:no_lines) - no_lines/2 )*dx;

tElapsed = toc(tStart);
disp(' '); disp(' ');
disp(['elapsed time: ', num2str(tElapsed/60000)]);


%%

for i = 1:N_elements
    part1 = zeros(round(times(i)*fs),N_elements_r);
    part2 = zeros(2000-size(RFframe,1),N_elements_r);
    RFframe_temp = vertcat(part1,RFframe(:,:,i),part2);
    RFframe2(1:size(RFframe_temp,1),:,i) = RFframe_temp;
end

for i = 1:N_elements
    plainRF2(:,i) = plainRF(:,i);
end
for i = 1:N_elements/2
    plainRF2(:,i) = plainRF(:,i);
end

% Modify for rotation uncertainty
angle = 0.1;
disp(['angle: ', num2str(angle)]);
I = plainRF2(:,N_elements/2:N_elements);
J = imrotate(I,angle,'bilinear','crop');
plainRF2(:,N_elements/2:N_elements) = J;

% Modify for axial/lateral uncertainty
% for i = N_elements/2+1:N_elements
%     %     if i + 3 < 129
%     % %     plainRF2(7:1202,i) = plainRF(1:1196,i);
%     %     plainRF2(1:1202,i) = plainRF(1:1202,i);
%     %     end
%     
%     xcut = 0*(-1);
%     ycut = 2*(-1);
%   %   plainRF2(:,i) = plainRF(:,i-cut);
%   if i -xcut<N_elements+1
%       if ycut >0
%           plainRF2(1:2000-ycut,i) = plainRF(1+ycut:2000,i-xcut);  
%       else
%           plainRF2(1-ycut:2000,i) = plainRF(1:2000+ycut,i-xcut);    
%       end
%   end
% %   plainRF2(1:1197,i) = plainRF(6:1202,i-cut);
% %     
% %     if i + cut < 129
% %      %   plainRF2(:,i) = plainRF(:,i+cut);
% %       plainRF2(2:1202,i) = plainRF(1:1201,i+cut);
% %     end
% 
% end

out_img = DAS_single(plainRF2(:,:), 128, 0.15);

bf_image = out_img;
bf_image = abs(hilbert(bf_image)); % Envelope detection
bf_image = bf_image / max(max(bf_image));

bf_image_p = 20*log10(bf_image + 0.001);
for i = 1:N_elements
    for j = 1:size(bf_image_p,1)
        if bf_image_p(j,i) < -30
            bf_image_p(j,i) = -30;
        end
    end
end
y = [1 size(bf_image_p(:,:),1)] / 40e6 * 1540 * 1e3;
x = [1 size(bf_image_p(:,:),2)] / N_elements * 38.4/4;

%%

cutoff = -16;

ind = find(bf_image_p >= cutoff);
coor = zeros(size(ind,1),2);

for i = 1:size(ind,1)
    
    [p q] = ind2sub(size(bf_image_p),ind(i));
    coor(i,1) = p; coor(i,2) = q;
    
end

pixelCount = max(size(coor))
widthX = max(coor(:,2)) - min(coor(:,2))
widthY = max(coor(:,1)) - min(coor(:,1))

figure;
imagesc(x,y,bf_image_p(750:1100,:))
colormap(gray);
title(['angle: ', num2str(angle), '  pixel count: ', num2str(pixelCount)]);

